==> html-list-1.0.7.tgz: package/src/index.jsx <==
/**
  * @author tianyanrong
  */
import React, { Component } from 'react';
import styles from './index.module.less';
import {getColorPalettes, getColorAlpha} from '@icode-run/component-layout/utils/colorParse';


class Text extends Component {
  state = {};

  getData = () => {
    const {dataKeys, data = []} = this.props;
    return data.map((dataItem,index) => {
      return dataKeys.map(item => {
        return dataItem[item.keyName];
      });
    })
  }

  countUp = (el, value, end, speed, type) => {
    let newValue = value + speed;
    if(type === 'less') {
      newValue = value - speed;
    }
    if(el) {
      el.innerHTML = newValue >= end ? end : newValue;
    }
    
    if((type === 'more' && newValue < end) || (type === 'less' && newValue > end)) {
      this.countUpTime = setTimeout(() => {
        this.countUp(el, newValue, end, speed, type);
      }, 20)
    }
  }

  setValue = (data) => {
    data.forEach((item, index) => {
      let el = document.getElementsByName(item.id);
      el = el && el[0];
      
      if(el && item.value !== el.innerHTML) {
        const end = parseInt(item.value, 10);
        const start = parseInt(el.innerHTML, 10) || 0;
        const speed = parseInt((end - start)/50, 10) || 1;
        this.countUp(el, start, end, speed, start < end ? 'more' : 'less');
      }

    })
  }

  componentDidMount() {
    const data = this.getData() || [];
    this.setValue(data);
  }
  componentDidUpdate() {
    const data = this.getData() || [];
    this.setValue(data);
  }

  idName = 'svgItem_'+(+new Date());

  render() {
    const { className = '', style = {}, global, parseOptions} = this.props;
    const data = this.getData() || [];
    let svg = '<div></div>';
    try{
      svg = parseOptions(data, this.props, {
        ...global,
        getColorPalettes: getColorPalettes,
        getColorAlpha: getColorAlpha,
      });
    }catch(e) {
      console.log('------get SVG配置 error', e);
    }
    return <div className={`${className || ''}`} style={style} dangerouslySetInnerHTML={{__html: svg}} >
     </div>;
  }
}
export default Text;

==> html-list-1.0.8.tgz: package/src/index.jsx <==
/**
  * @author tianyanrong
  */
import React, { Component } from 'react';
import styles from './index.module.less';
import {getColorPalettes, getColorAlpha} from '@icode-run/component-layout/utils/colorParse';


class Text extends Component {
  state = {};

  getData = () => {
    const {dataKeys = [], data = []} = this.props;
    return data.map((dataItem,index) => {
      return dataKeys.map(item => {
        return dataItem[item.keyName];
      });
    })
  }

  countUp = (el, value, end, speed, type) => {
    let newValue = value + speed;
    if(type === 'less') {
      newValue = value - speed;
    }
    if(el) {
      el.innerHTML = newValue >= end ? end : newValue;
    }
    
    if((type === 'more' && newValue < end) || (type === 'less' && newValue > end)) {
      this.countUpTime = setTimeout(() => {
        this.countUp(el, newValue, end, speed, type);
      }, 20)
    }
  }

  setValue = (data) => {
    data.forEach((item, index) => {
      let el = document.getElementsByName(item.id);
      el = el && el[0];
      
      if(el && item.value !== el.innerHTML) {
        const end = parseInt(item.value, 10);
        const start = parseInt(el.innerHTML, 10) || 0;
        const speed = parseInt((end - start)/50, 10) || 1;
        this.countUp(el, start, end, speed, start < end ? 'more' : 'less');
      }

    })
  }

  componentDidMount() {
    const data = this.getData() || [];
    this.setValue(data);
  }
  componentDidUpdate() {
    const data = this.getData() || [];
    this.setValue(data);
  }

  idName = 'svgItem_'+(+new Date());

  render() {
    const { className = '', style = {}, global, parseOptions} = this.props;
    const data = this.getData() || [];
    let svg = '<div></div>';
    try{
      svg = parseOptions(data, this.props, {
        ...global,
        getColorPalettes: getColorPalettes,
        getColorAlpha: getColorAlpha,
      });
    }catch(e) {
      console.log('------get SVG配置 error', e);
    }
    return <div className={`${className || ''}`} style={style} dangerouslySetInnerHTML={{__html: svg}} >
     </div>;
  }
}
export default Text;
